@@ -1,12 +1,6 @@
 # -*- coding: utf-8 -*-
 """
-Datatypes and parsers for the various structures, specific to Redis Gears.
-
-These datatypes are returend from various redgrease functions, merely for the purpose
-of providig more convenient structure, typing and documentation compared to the native
-'list-based' structures.
-
-They are generally not intended to be instantiated by end-users.
+Exceptions
 """
 __author__ = "Anders Åström"
 __contact__ = "anders@lyngon.com"
