@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# from __future__ import annotations
+
 """
 Sugar classes for the various Gears Reader types.
 """
@@ -31,11 +33,11 @@ from typing import Callable, Dict, Iterable, Optional
 
 import redgrease.gears
 import redgrease.sugar
-import redgrease.typing
 import redgrease.utils
+from redgrease.typing import OutputRecord, Record
 
 
-class GearReader(redgrease.gears.PartialGearFunction[redgrease.typing.OutputRecord]):
+class GearReader(redgrease.gears.OpenGearFunction[OutputRecord]):
     """Base class for the Reader sugar classes.
 
     Extends `redgrease.runtime.GearsBuilder' with arguments for collecting
@@ -75,14 +77,14 @@ class GearReader(redgrease.gears.PartialGearFunction[redgrease.typing.OutputReco
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         reader_op = redgrease.gears.Reader(reader, defaultArg, desc)
         super().__init__(operation=reader_op, requirements=requirements)
 
 
-class KeysReader(GearReader[redgrease.typing.Record]):
+class KeysReader(GearReader[Record]):
     """KeysReader is a convenience class for GearsBuilder("KeysReader", ...)"""
 
     def __init__(
@@ -91,7 +93,7 @@ class KeysReader(GearReader[redgrease.typing.Record]):
         desc: str = None,
         requirements: Optional[Iterable[str]] = None,
     ):
-        """Instantiate a KeysReader partial Gear function.
+        """Instantiate a KeysReader "open" Gear function.
 
         Args:
             default_key_pattern (str, optional):
@@ -103,7 +105,7 @@ class KeysReader(GearReader[redgrease.typing.Record]):
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         super().__init__(
@@ -114,7 +116,7 @@ class KeysReader(GearReader[redgrease.typing.Record]):
         )
         self.default_key_pattern = default_key_pattern
 
-    def values(self, type=..., event=...) -> redgrease.gears.PartialGearFunction:
+    def values(self, type=..., event=...) -> redgrease.gears.OpenGearFunction:
         """Filter out and select the values of the records only.
 
         Args:
@@ -128,18 +130,18 @@ class KeysReader(GearReader[redgrease.typing.Record]):
             event (Union[str, Container[str]], optional):
                 A single string, or a container of several strings, representing the
                 Redis command or event `that .
-                Defaults to ... (Ellipsis), menaing any event.
+                Defaults to ... (Ellipsis), meaning any event.
 
         Returns:
-            PartialGearFunction:
-                A new partial gear function generating the matching values.
+            OpenGearFunction:
+                A new "open" gear function generating the matching values.
         """
-        f: redgrease.gears.PartialGearFunction = self
+        f: redgrease.gears.OpenGearFunction = self
         if type != ... or event != ...:
             f = f.filter(redgrease.utils.dict_filter(type=type, event=event))
         return f.map(lambda record: record["value"])
 
-    def keys(self, type=..., event=...) -> redgrease.gears.PartialGearFunction[str]:
+    def keys(self, type=..., event=...) -> redgrease.gears.OpenGearFunction[str]:
         """Filter out and select the keys of the records only.
 
         Args:
@@ -153,20 +155,20 @@ class KeysReader(GearReader[redgrease.typing.Record]):
             event (Union[str, Container[str]], optional):
                 A single string, or a container of several strings, representing the
                 Redis command or event `that .
-                Defaults to ... (Ellipsis), menaing any event.
+                Defaults to ... (Ellipsis), meaning any event.
 
         Returns:
-            PartialGearFunction[str]:
-                A new partial gear function generating the matching keys.
+            OpenGearFunction[str]:
+                A new "open" gear function generating the matching keys.
         """
-        f: redgrease.gears.PartialGearFunction = self
+        f: redgrease.gears.OpenGearFunction = self
         if type != ... or event != ...:
             f = f.filter(redgrease.utils.dict_filter(type=type, event=event))
         return f.map(lambda record: record["key"])
 
     def records(
-        self, type=None, event=...
-    ) -> redgrease.gears.PartialGearFunction[redgrease.utils.Record]:
+        self, type=..., event=...
+    ) -> redgrease.gears.OpenGearFunction[redgrease.utils.Record]:
         """Filter out and map the records to `redgrease.utils.Record` objects.
 
         This provides the fields `key`, `value`, `type` and `event` as typed attributes
@@ -184,13 +186,13 @@ class KeysReader(GearReader[redgrease.typing.Record]):
             event (Union[str, Container[str]], optional):
                 A single string, or a container of several strings, representing the
                 Redis command or event `that.
-                Defaults to ... (Ellipsis), menaing any event.
+                Defaults to ... (Ellipsis), meaning any event.
 
         Returns:
-            PartialGearFunction[redgrease.utils.Record]:
-                A new partial gear function generating the matching Record values.
+            OpenGearFunction[redgrease.utils.Record]:
+                A new "open" gear function generating the matching Record values.
         """
-        f: redgrease.gears.PartialGearFunction = self
+        f: redgrease.gears.OpenGearFunction = self
         if type != ... or event != ...:
             f = f.filter(redgrease.utils.dict_filter(type=type, event=event))
         return f.map(redgrease.utils.record)
@@ -205,7 +207,7 @@ class KeysOnlyReader(GearReader[str]):
         desc: str = None,
         requirements: Optional[Iterable[str]] = None,
     ):
-        """Instantiate a KeysOnlyReader partial Gear function.
+        """Instantiate a KeysOnlyReader "open" Gear function.
 
         Args:
             default_key_pattern (str, optional):
@@ -217,7 +219,7 @@ class KeysOnlyReader(GearReader[str]):
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         super().__init__(
@@ -229,7 +231,7 @@ class KeysOnlyReader(GearReader[str]):
         self.default_key_pattern = default_key_pattern
 
 
-class StreamReader(GearReader[redgrease.typing.Record]):
+class StreamReader(GearReader[Record]):
     """StreamReader is a convenience class for GearsBuilder("StreamReader", ...)"""
 
     def __init__(
@@ -238,7 +240,7 @@ class StreamReader(GearReader[redgrease.typing.Record]):
         desc: str = None,
         requirements: Optional[Iterable[str]] = None,
     ):
-        """Instantiate a StreamReader partial Gear function.
+        """Instantiate a StreamReader "open" Gear function.
 
         Args:
             default_key_pattern (str, optional):
@@ -250,7 +252,7 @@ class StreamReader(GearReader[redgrease.typing.Record]):
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         super().__init__(
@@ -261,27 +263,27 @@ class StreamReader(GearReader[redgrease.typing.Record]):
         )
         self.default_key_pattern = default_key_pattern
 
-    def values(self) -> redgrease.gears.PartialGearFunction[Dict]:
+    def values(self) -> redgrease.gears.OpenGearFunction[Dict]:
         """Select the values of the stream only.
 
         Returns:
-            PartialGearFunction:
-                A new partial gear function generating values.
+            OpenGearFunction:
+                A new "open" gear function generating values.
         """
         return self.map(lambda record: record["value"])
 
-    def keys(self) -> redgrease.gears.PartialGearFunction[str]:
+    def keys(self) -> redgrease.gears.OpenGearFunction[str]:
         """Select the keys, i.e. stream names, only.
 
         Returns:
-            PartialGearFunction[str]:
-                A new partial gear function generating names.
+            OpenGearFunction[str]:
+                A new "open" gear function generating names.
         """
         return self.map(lambda record: record["key"])
 
     def records(
         self,
-    ) -> redgrease.gears.PartialGearFunction[redgrease.utils.StreamRecord]:
+    ) -> redgrease.gears.OpenGearFunction[redgrease.utils.StreamRecord]:
         """Filter out and map the records to `redgrease.utils.StreamRecord` objects.
 
         This provides the fields `key`, `id` and `value` as typed attributes on an
@@ -289,8 +291,8 @@ class StreamReader(GearReader[redgrease.typing.Record]):
         to work with.
 
         Returns:
-            PartialGearFunction[redgrease.utils.Record]:
-                A new partial gear function generating the matching Record values.
+            OpenGearFunction[redgrease.utils.Record]:
+                A new "open" gear function generating the matching Record values.
         """
         return self.map(redgrease.utils.stream_record)
 
@@ -303,7 +305,7 @@ class PythonReader(GearReader):
         desc: str = None,
         requirements: Optional[Iterable[str]] = None,
     ):
-        """Instantiate a PythonReader partial Gear function.
+        """Instantiate a PythonReader "open" Gear function.
 
         Args:
             desc (str, optional):
@@ -311,7 +313,7 @@ class PythonReader(GearReader):
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         super().__init__(
@@ -329,7 +331,7 @@ class ShardsIDReader(GearReader[str]):
         desc: str = None,
         requirements: Optional[Iterable[str]] = None,
     ):
-        """Instantiate a ShardsIDReader partial Gear function.
+        """Instantiate a ShardsIDReader "open" Gear function.
 
         Args:
             desc (str, optional):
@@ -337,7 +339,7 @@ class ShardsIDReader(GearReader[str]):
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         super().__init__(
@@ -355,7 +357,7 @@ class CommandReader(GearReader):
         desc: str = None,
         requirements: Optional[Iterable[str]] = None,
     ):
-        """Instantiate a CommandReader partial Gear function.
+        """Instantiate a CommandReader "open" Gear function.
 
         Args:
             desc (str, optional):
@@ -363,7 +365,7 @@ class CommandReader(GearReader):
                 Defaults to None.
 
             requirements (Iterable[str], optional):
-                Package lependencies for the gear train.
+                Package dependencies for the gear train.
                 Defaults to None.
         """
         super().__init__(
@@ -372,7 +374,7 @@ class CommandReader(GearReader):
             requirements=requirements,
         )
 
-    def args(self, max_count: int = None) -> redgrease.gears.PartialGearFunction:
+    def args(self, max_count: int = None) -> redgrease.gears.OpenGearFunction:
         """Ignore the trigger name and take only the arguments following the trigger.
 
         Args:
@@ -381,8 +383,8 @@ class CommandReader(GearReader):
                 Defaults to None.
 
         Returns:
-            redgrease.gears.PartialGearFunction:
-                A new partial gear function only generating the trigger arguments.
+            redgrease.gears.OpenGearFunction:
+                A new "open" gear function only generating the trigger arguments.
         """
         if max_count:
             max_count += 1
@@ -390,21 +392,21 @@ class CommandReader(GearReader):
 
     def apply(
         self,
-        fun: Callable[..., redgrease.typing.OutputRecord],
+        fun: Callable[..., OutputRecord],
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
         **kwargs,
-    ) -> redgrease.gears.PartialGearFunction[redgrease.typing.OutputRecord]:
+    ) -> redgrease.gears.OpenGearFunction[OutputRecord]:
         """Apply a function to the trigger arguments.
 
         Args:
-            fun (Callable[..., redgrease.typing.OutputRecord]):
+            fun (Callable[..., :data:`redgrease.typing.OutputRecord`]):
                 The function to call with the trigger arguments.
 
         Returns:
-            redgrease.gears.PartialGearFunction[redgrease.typing.OutputRecord]:
-                A new partial gear function generating the results of the function.
+            redgrease.gears.OpenGearFunction[:data:`redgrease.typing.OutputRecord`]:
+                A new "open" gear function generating the results of the function.
         """
         return self.map(
             lambda args: fun(*args[1:]), requirements=requirements, **kwargs
