@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+# from __future__ import annotations
+
 """
 Redgrease's (overloaded) variants of the symbols loaded per default into the top level
 namespace of Gear functions in the Redis server Python runtime.
@@ -22,23 +24,36 @@ The above copyright notice and this permission notice shall be included in all c
 THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHsER LIABILITY, WHETHER IN AN ACTION OF
+ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
  CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
  OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
-from typing import TYPE_CHECKING, Hashable, Iterable, TypeVar
+from typing import Hashable, Iterable, TypeVar
 
 import redgrease.gears
 
-if TYPE_CHECKING:
-    import redgrease.typing as optype
+# if TYPE_CHECKING:
+from redgrease.typing import (
+    Accumulator,
+    BatchReducer,
+    Expander,
+    Extractor,
+    Filterer,
+    InputRecord,
+    Key,
+    Mapper,
+    OutputRecord,
+    Processor,
+    Reducer,
+    Registrator,
+)
 
 T = TypeVar("T")
 
 
 class GearsBuilder(redgrease.gears.OpenGearFunction):
     """The RedisGears :ref:`GearsBuilder` class is imported to the runtime's
-    environment by default, and this class is a RedgGrease wrapper of it.
+    environment by default, and this class is a RedGrease wrapper of it.
 
     It exposes the functionality of the function's `context builder
     <https://oss.redislabs.com/redisgears/1.0/functions.html#context-builder>`_.
@@ -50,7 +65,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         The :class:`.GearsBuilder` is a subclass of :class:`.gears.OpenGearFunction`,
         but unlike other OpenGearFunctions, the GearsBuilder mutates an internal
         GearFunction instead of creating a new one for each operation.
-        This behaviour is deliberate, in order to be consistent with the original
+        This behavior is deliberate, in order to be consistent with the original
         GearsBuilder.
     """
 
@@ -134,20 +149,20 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
             **kwargs,
         )
 
-    def register(  # noqa: C901
+    def register(
         self,
         prefix: str = "*",
         convertToStr: bool = True,
         collect: bool = True,
         # Helpers, all must be None
         mode: str = None,
-        onRegistered: "optype.Callback" = None,
+        onRegistered: Registrator = None,
         eventTypes: Iterable[str] = None,
         keyTypes: Iterable[str] = None,
         readValue: bool = None,
         batch: int = None,
         duration: int = None,
-        onFailedPolcy: str = None,
+        onFailedPolicy: str = None,
         onFailedRetryInterval: int = None,
         trimStream: bool = None,
         trigger: str = None,  # Reader Specific: CommandReader
@@ -170,7 +185,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
             readValue=readValue,
             batch=batch,
             duration=duration,
-            onFailedPolcy=onFailedPolcy,
+            onFailedPolicy=onFailedPolicy,
             onFailedRetryInterval=onFailedRetryInterval,
             trimStream=trimStream,
             trigger=trigger,  # CommandReader specific
@@ -183,7 +198,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def map(
         self,
-        op: "optype.Mapper[optype.InputRecord, optype.OutputRecord]",
+        op: Mapper[InputRecord, OutputRecord],
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -193,13 +208,13 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         records.
 
         Args:
-            op (redgrease.typing.Mapper):
+            op :data:`redgrease.typing.Mapper`):
                 Function to map on the input records.
                 The function must take one argument as input (input record) and
                 return something as an output (output record).
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -216,7 +231,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def flatmap(
         self,
-        op: "optype.Expander[optype.InputRecord, optype.OutputRecord]" = None,
+        op: Expander[InputRecord, OutputRecord] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -226,7 +241,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         of records.
 
         Args:
-            op (redgrease.typing.Expander, optional):
+            op :data:`redgrease.typing.Expander`, optional):
                 Function to map on the input records.
                 The function must take one argument as input (input record) and
                 return an iterable as an output (output records).
@@ -234,7 +249,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 be expanded.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -253,7 +268,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def foreach(
         self,
-        op: "optype.Processor[optype.InputRecord]",
+        op: Processor[InputRecord],
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -262,13 +277,13 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         """Instance-local :ref:`op_foreach` operation performs one-to-the-same (1=1) mapping.
 
         Args:
-            op (redgrease.typing.Processor):
+            op :data:`redgrease.typing.Processor`):
                 Function to run on each of the input records.
                 The function must take one argument as input (input record) and
                 should not return anything.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -287,7 +302,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def filter(
         self,
-        op: "optype.Filterer[optype.InputRecord]" = None,
+        op: Filterer[InputRecord] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -297,16 +312,16 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         filtering of records.
 
         Args:
-            op (redgrease.typing.Filterer, optional):
+            op :data:`redgrease.typing.Filterer`, optional):
                 Function to apply on the input records, to decide which ones to keep.
                 The function must take one argument as input (input record) and
                 return a bool. The input records evaluated to `True` will be kept as
                 output records.
                 Defaults to the 'identity-function', i.e. records are filtered based on
-                their own truiness or falsiness.
+                their own trueess or falseness.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -325,7 +340,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def accumulate(
         self,
-        op: "optype.Accumulator[T, optype.InputRecord]" = None,
+        op: Accumulator[T, InputRecord] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -335,7 +350,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         records.
 
         Args:
-            op (redgrease.typing.Accumulator, optional):
+            op :data:`redgrease.typing.Accumulator`, optional):
                 Function to to apply on the input records.
                 The function must take two arguments as input:
                     - An accumulator value, and
@@ -347,7 +362,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 all inputs.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -366,8 +381,8 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def localgroupby(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, optype.Key]" = None,
-        reducer: "optype.Reducer[optype.Key, T, optype.InputRecord]" = None,
+        extractor: Extractor[InputRecord, Key] = None,
+        reducer: Reducer[Key, T, InputRecord] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -377,14 +392,14 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         of records.
 
         Args:
-            extractor (redgrease.typing.Extractor, optional):
+            extractor :data:`redgrease.typing.Extractor`, optional):
                 Function to apply on the input records, to extact the grouping key.
                 The function must take one argument as input (input record) and
                 return a string (key).
                 The groups are defined by the value of the key.
                 Defaults to the hash of the input.
 
-            reducer (redgrease.typing.Reducer, optional):
+            reducer :data:`redgrease.typing.Reducer`, optional):
                 Function to apply on the records of each group, to reduce to a single
                 value (per group).
                 The function must take (a) a key, (b) an input record and (c) a
@@ -395,7 +410,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 all inputs, for each group.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -434,7 +449,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 Defaults to 0.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -468,7 +483,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def repartition(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, Hashable]",
+        extractor: Extractor[InputRecord, Hashable],
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -478,17 +493,17 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         them between shards.
 
         Args:
-            extractor (redgrease.typing.Extractor):
+            extractor :data:`redgrease.typing.Extractor`):
                 Function that takes a record and calculates a key that is used to
                 determine the hash slot, and consequently the shard, that the record
                 should migrate to to.
                 The function must take one argument as input (input record) and
                 return a string (key).
                 The hash slot, and consequently the destination shard, is determined by
-                hthe value of the key.
+                the value of the key.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -508,8 +523,8 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
     def aggregate(
         self,
         zero: T = None,
-        seqOp: "optype.Accumulator[T, optype.InputRecord]" = None,
-        combOp: "optype.Accumulator[T, T]" = None,
+        seqOp: Accumulator[T, InputRecord] = None,
+        combOp: Accumulator[T, T] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -523,31 +538,31 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 The initial / zero value of the accumulator variable.
                 Defaults to an empty list.
 
-            seqOp (redgrease.typing.Accumulator, optional):
+            seqOp :data:`redgrease.typing.Accumulator`, optional):
                 A function to be applied on each of the input records, locally per
                 shard.
                 It must take two parameters:
                 - an accumulator value, from previous calls
                 - an input record
-                The functoin aggregates the input into the accumulator variable,
+                The function aggregates the input into the accumulator variable,
                 which stores the state between the function's invocations.
                 The function must return the accumulator's updated value.
                 Defaults to addition, if 'zero' is a number and to a list accumulator
                 if 'zero' is a list.
 
-            combOp (redgrease.typing.Accumulator, optional):
+            combOp :data:`redgrease.typing.Accumulator`, optional):
                 A function to be applied on each of the aggregated results of the local
                 aggregation (i.e. the output of `seqOp`).
                 It must take two parameters:
                 - an accumulator value, from previous calls
                 - an input record
-                The functoin aggregates the input into the accumulator variable,
+                The function aggregates the input into the accumulator variable,
                 which stores the state between the function's invocations.
                 The function must return the accumulator's updated value.
                 Defaults to re-use the `seqOp` function.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -570,10 +585,10 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def aggregateby(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, optype.Key]" = None,
+        extractor: Extractor[InputRecord, Key] = None,
         zero: T = None,
-        seqOp: "optype.Reducer[optype.Key, T, optype.InputRecord]" = None,
-        combOp: "optype.Reducer[optype.Key, T, T]" = None,
+        seqOp: Reducer[Key, T, InputRecord] = None,
+        combOp: Reducer[Key, T, T] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -583,7 +598,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         separated on each key, extracted using the extractor.
 
         Args:
-            extractor (redgrease.typing.Extractor, optional):
+            extractor :data:`redgrease.typing.Extractor`, optional):
                 Function to apply on the input records, to extact the grouping key.
                 The function must take one argument as input (input record) and
                 return a string (key).
@@ -594,30 +609,30 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 The initial / zero value of the accumulator variable.
                 Defaults to an empty list.
 
-            seqOp (redgrease.typing.Accumulator, optional):
+            seqOp :data:`redgrease.typing.Accumulator`, optional):
                 A function to be applied on each of the input records, locally per
                 shard and group.
                 It must take two parameters:
                 - an accumulator value, from previous calls
                 - an input record
-                The functoin aggregates the input into the accumulator variable,
+                The function aggregates the input into the accumulator variable,
                 which stores the state between the function's invocations.
                 The function must return the accumulator's updated value.
                 Defaults to a list reducer.
 
-            combOp (redgrease.typing.Accumulator):
+            combOp :data:`redgrease.typing.Accumulator`):
                 A function to be applied on each of the aggregated results of the local
                 aggregation (i.e. the output of `seqOp`).
                 It must take two parameters:
                 - an accumulator value, from previous calls
                 - an input record
-                The functoin aggregates the input into the accumulator variable,
+                The function aggregates the input into the accumulator variable,
                 which stores the state between the function's invocations.
                 The function must return the accumulator's updated value.
                 Defaults to re-use the `seqOp` function.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -641,8 +656,8 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def groupby(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, optype.Key]" = None,
-        reducer: "optype.Reducer[optype.Key, T, optype.InputRecord]" = None,
+        extractor: Extractor[InputRecord, Key] = None,
+        reducer: Reducer[Key, T, InputRecord] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -652,14 +667,14 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         grouping of records.
 
         Args:
-            extractor (redgrease.typing.Extractor, optional):
+            extractor :data:`redgrease.typing.Extractor`, optional):
                 Function to apply on the input records, to extact the grouping key.
                 The function must take one argument as input (input record) and
                 return a string (key).
                 The groups are defined by the value of the key.
                 Defaults to the hash of the input.
 
-            reducer (redgrease.typing.Reducer, optional):
+            reducer :data:`redgrease.typing.Reducer`, optional):
                 Function to apply on the records of each group, to reduce to a single
                 value (per group).
                 The function must take (a) a key, (b) an input record and (c) a
@@ -669,7 +684,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 Defaults to a list reducer.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -688,8 +703,8 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def batchgroupby(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, optype.Key]" = None,
-        reducer: "optype.BatchReducer[optype.Key, T, optype.InputRecord]" = None,
+        extractor: Extractor[InputRecord, Key] = None,
+        reducer: BatchReducer[Key, T, InputRecord] = None,
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
@@ -702,14 +717,14 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 during runtime. Consider using the GroupBy
 
         Args:
-            extractor (redgrease.typing.Extractor, optional):
+            extractor :data:`redgrease.typing.Extractor`, optional):
                 Function to apply on the input records, to extact the grouping key.
                 The function must take one argument as input (input record) and
                 return a string (key).
                 The groups are defined by the value of the key.
                 Defaults to the hash of the input.
 
-            reducer (redgrease.typing.Reducer):
+            reducer :data:`redgrease.typing.Reducer`):
                 Function to apply on the records of each group, to reduce to a single
                 value (per group).
                 The function must take (a) a key, (b) an input record and (c) a
@@ -744,11 +759,11 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
         Args:
             reverse (bool, optional):
-                Sort in descending order (higer to lower).
+                Sort in descending order (higher to lower).
                 Defaults to True.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -799,16 +814,16 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def countby(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, Hashable]" = lambda x: str(x),
+        extractor: Extractor[InputRecord, Hashable] = lambda x: str(x),
         # Other Redgrease args
         requirements: Iterable[str] = None,
         # Other Redis Gears args
         **kwargs,
     ) -> "GearsBuilder":
-        """Distributed :ref:`op_countby` operation countinig the records grouped by key.
+        """Distributed :ref:`op_countby` operation counting the records grouped by key.
 
         Args:
-            extractor (redgrease.typing.Extractor):
+            extractor :data:`redgrease.typing.Extractor`):
                 Function to apply on the input records, to extact the grouping key.
                 The function must take one argument as input (input record) and
                 return a string (key).
@@ -816,7 +831,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 Defaults to 'lambda x: str(x)'.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -839,7 +854,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
     def avg(
         self,
-        extractor: "optype.Extractor[optype.InputRecord, float]" = lambda x: float(
+        extractor: Extractor[InputRecord, float] = lambda x: float(
             x if isinstance(x, (int, float, str)) else str(x)
         ),
         # Other Redgrease args
@@ -850,7 +865,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
         """Distributed :ref:`op_avg` operation, calculating arithmetic average of the records.
 
         Args:
-            extractor (redgrease.typing.Extractor):
+            extractor :data:`redgrease.typing.Extractor`):
                 Function to apply on the input records, to extact the grouping key.
                 The function must take one argument as input (input record) and
                 return a string (key).
@@ -858,7 +873,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
                 Defaults to 'lambda x: float(x)'.
 
             requirements (Iterable[str], optional):
-                Additional requirements / dedpendency Python packages.
+                Additional requirements / dependency Python packages.
                 Defaults to None.
 
             **kwargs:
@@ -871,7 +886,7 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
                 Note that for GearBuilder this method does **not** return a new
                 GearFunction, but instead returns the same GearBuilder, but with its
-                internal function updaded.
+                internal function updated.
         """
         self._function = self._function.avg(
             extractor=extractor,
@@ -885,10 +900,10 @@ class GearsBuilder(redgrease.gears.OpenGearFunction):
 
 
 GB = GearsBuilder
-"""Convnenience shorthand for GearsBuilder."""
+"""Convenience shorthand for GearsBuilder."""
 
 
-# # Suppress warnings for missing redisgears packagae
+# # Suppress warnings for missing redisgears package
 # # As this package only lives on the Redis Gears server
 # pyright: reportMissingImports=false
 class atomic:
@@ -901,14 +916,14 @@ class atomic:
     def __init__(self):
         from redisgears import atomicCtx as redisAtomic
 
-        self.atomic = redisAtomic()
+        self._atomic = redisAtomic()
 
     def __enter__(self):
-        self.atomic.__enter__()
+        self._atomic.__enter__()
         return self
 
     def __exit__(self, *args, **kwargs):
-        self.atomic.__exit__(*args, **kwargs)
+        self._atomic.__exit__(*args, **kwargs)
 
 
 def execute(command: str, *args) -> bytes:
@@ -971,7 +986,7 @@ def log(message: str, level: str = "notice"):
                 - 'debug'
                 - 'verbose'
                 - 'notice'
-                - 'wartning'
+                - 'warning'
 
             Defaults to 'notice'.
     """
@@ -1009,6 +1024,60 @@ def gearsConfigGet(key: str, default=None) -> str:
     return redisGearsConfigGet(key)
 
 
+class gearsFuture:
+    """The gearsFuture object allows another thread/process to process the
+    record.
+
+    Returning this object from a step's operation tells RedisGears to suspend execution
+    until background processing had finished/failed.
+
+    The gearsFuture object provides two control methods: ``continueRun()`` and
+    ``continueFailed()``. Both methods are thread-safe and can be called at any time to
+    signal that the background processing has finished.
+
+    ``continueRun()`` signals success and its argument is a record for the main process.
+    ``continueFailed()`` reports a failure to the main process and its argument is a
+    string describing the failure.
+
+    Calling gearsFuture() is supported only from the context of the following
+    operations:
+
+    * :ref:`Map`
+    * flatmap
+    * filter
+    * foreach
+    * aggregate
+    * aggregateby
+
+    An attempt to create a ``gearsFuture`` object outside of the supported contexts
+    will result in an exception.
+    """
+
+    def __init__(self):
+        from redisgears import gearsFutureCtx as redisGearsFuture
+
+        self._gearsFuture = redisGearsFuture()
+
+    def continueRun(self, record) -> None:
+        """Signals success and its argument is a record for the main process.
+
+        Args:
+            record (Any):
+                Record to yield to the blocked Gear function.
+        """
+        return self._gearsFuture.continueRun(record)
+
+    def continueFail(self, message: str):
+        """Reports a failure to the main process and its argument is a string describing
+        the failure.
+
+        Args:
+            message (str):
+                Message describing the failure.
+        """
+        return self._gearsFuture.continueFail(message)
+
+
 def run(
     function: redgrease.gears.GearFunction,
     builder: GearsBuilder,
